==> 0.10.1.tar.gz: lib/coupons_module/CouponsListPage.dart <==
import 'dart:convert';

import 'package:flutter/material.dart';
import 'package:loyalty_management_tool/utils/localization.dart';

import 'package:shared_preferences/shared_preferences.dart';

import '../NetworkFile/calls.dart';
import '../bloc/common_widgets/customgridDelegate.dart';
import '../models/base_res.dart';
import '../models/couponenums.dart';
import '../models/couponlisting.dart';
import '../utils/CustomPaginator.dart';
import '../utils/basicInfo.dart';
import '../utils/customcard.dart';
import '../utils/paginator.dart';
import '../utils/utility_class.dart';
import 'coupondetailpage.dart';
import 'couponhistoryitem.dart';
import 'couponlistitem.dart';
import 'gift_item_card.dart';

// ignore: must_be_immutable
class CouponsListPage extends StatefulWidget {
  Function(CouponListItem)? giftCardSelectCallback;
  Function? fetchData;
  bool isGift;
  CouponsListPage(
      {required this.giftCardSelectCallback,
      this.isGift = false,
      this.fetchData});

  @override
  _CouponsListPage createState() => _CouponsListPage();
}

class _CouponsListPage extends State<CouponsListPage> {
  GlobalKey<PaginatorState> paginatorKey = GlobalKey();
  String? searchVal;
  List<CommonCardData> couponList = [];
  SharedPreferences? prefs;
  BasicInfo? basicInfo = BasicInfo();
  @override
  void initState() {
    super.initState();
  }

  // void setSharedPreferences() async {
  //   prefs = await SharedPreferences.getInstance();
  //   refresh();
  // }

  void onsearchValueChanged(String text) {
    searchVal = text;
    refresh();
  }

  refresh() {
    paginatorKey.currentState!.changeState(resetState: true);
  }

  Future<Null> refreshList() async {
    refresh();
    await new Future.delayed(new Duration(seconds: 2));

    return null;
  }

  @override
  Widget build(BuildContext context) {
    return Container(
      child: RefreshIndicator(
        onRefresh: refreshList,
        child: Paginator.gridView(
          key: paginatorKey,
          scrollPhysics: BouncingScrollPhysics(),
          padding: EdgeInsets.only(top: 16),
          pageLoadFuture: fetchList,
          pageItemsGetter: CustomPaginator(context).listItemsGetter,
          listItemBuilder: giftItemBuilder,
          loadingWidgetBuilder: CustomPaginator(context).loadingWidgetMaker,
          errorWidgetBuilder: CustomPaginator(context).errorWidgetMaker,
          emptyListWidgetBuilder: emptyListWidgetMaker,
          totalItemsGetter: CustomPaginator(context).totalPagesGetter,
          pageErrorChecker:(data){return false;},
          gridDelegate: SliverGridDelegateWithFixedCrossAxisCountAndFixedHeight(
              crossAxisCount: 3, height: 230),
        ),
      ),
    );
  }

  Future<CouponListResponse> fetchList(int page) async {
    prefs ??= await SharedPreferences.getInstance();
    CouponListRequest payload = CouponListRequest();
    payload.pageNumber = page;
    payload.pageSize = 20;
    payload.personId = basicInfo!.userId.toString();
    payload.entityType = widget.isGift ? "GIFT" : "GIFT,COUPON";
    var data = jsonEncode(payload);
    var res = await Calls().call(data, context,basicInfo!.rewardCouponList);

    return CouponListResponse.fromJson(res);
  }

  Widget giftItemBuilder(itemData, int index) {
    CouponListItem data = itemData;
    return InkWell(
      onTap: () {
        if (widget.isGift) {
          widget.giftCardSelectCallback!(data);
        } else {
          Navigator.push(
              context,
              MaterialPageRoute(
                  builder: (context) => CouponDetailPage(
                        couponData: data,
                        showQr: false,
                        isGift: widget.isGift,
                      ))).then((value) {});
        }
      },
      child: GiftItemCard(
        imageUrl: data.couponImage,
        title: data.couponProvider ?? "Company name",
        subtitle1: getSubtitle(data),
        subtitle2:
            "Exp. ${Utility().getDateFormat(basicInfo!.dateFormat, DateTime.parse(data.validTill!))}",
      ),
    );
  }

  String getSubtitle(CouponListItem data) {
    if (data.couponDiscountType == COUPON_DISCOUNT_TYPE.Amount.type) {
      return "${basicInfo!.currencySymbol} ${data.couponDiscount.toString()}";
    } else {
      return "${data.couponDiscount.toString()}%"
          "";
    }
  }

  Widget emptyListWidgetMaker(CouponListResponse? pageData) {
    return CustomPaginator(context).emptyListWidgetMaker(pageData,
        message: AppLocalizationsRewards.of(context)!.translate('coming_soon'));
  }
}

class RedeemedCouponsListPage extends StatefulWidget {
  final bool isGift;
  RedeemedCouponsListPage({this.isGift = false});
  @override
  _RedeemedCouponsListPage createState() => _RedeemedCouponsListPage();
}

class _RedeemedCouponsListPage extends State<RedeemedCouponsListPage> {
  GlobalKey<PaginatorState> paginatorKey = GlobalKey();
  SharedPreferences? prefs;
  String? searchVal;
  List<CommonCardData> couponList = [];
  BasicInfo? basicInfo = BasicInfo();
  @override
  void initState() {
    super.initState();
  }

  void onsearchValueChanged(String text) {
    searchVal = text;
    refresh();
  }

  refresh() {
    paginatorKey.currentState!.changeState(resetState: true);
  }

  Future<Null> refreshList() async {
    refresh();
    await new Future.delayed(new Duration(seconds: 2));
    return null;
  }

  @override
  Widget build(BuildContext context) {
    // setSharedPreferences();
    return Paginator.listView(
        key: paginatorKey,
        scrollPhysics: BouncingScrollPhysics(),
        padding: EdgeInsets.only(top: 16),
        pageLoadFuture: fetchList,
        pageItemsGetter: CustomPaginator(context).listItemsGetter,
        listItemBuilder: listItemBuilder,
        loadingWidgetBuilder: CustomPaginator(context).loadingWidgetMaker,
        errorWidgetBuilder: CustomPaginator(context).errorWidgetMaker,
        emptyListWidgetBuilder: emptyListWidgetMaker,
        totalItemsGetter: CustomPaginator(context).totalPagesGetter, pageErrorChecker: (CouponListResponse pageData) { return false; },
);
  }

  Future<CouponListResponse> fetchList(int page) async {
    prefs ??= await SharedPreferences.getInstance();
    CouponListRequest payload = CouponListRequest();
    payload.pageNumber = page;
    payload.pageSize = 20;
    payload.personId = basicInfo!.toString();
    payload.entityType = widget.isGift ? 'GIFT' : "";
    var data = jsonEncode(payload);
    var res = await Calls().call(data, context, basicInfo!.myCouponList);
    return CouponListResponse.fromJson(res);
  }

  Widget listItemBuilder(value, int index) {
    CouponListItem item = value;
    return GestureDetector(
        onTap: () {
          Navigator.push(
              context,
              MaterialPageRoute(
                  builder: (context) => CouponDetailPage(
                      couponData: item, showQr: true, isGift: widget.isGift)));
        },
        child: Container(
          padding: EdgeInsets.only(left: 8, right: 8),
          child: appListCard(
            // elevation: 3,
            padding: EdgeInsets.all(0),
            child: CouponListItemCard(
              imageWidth: 124,
              imageHeight: 124,
              title: item.couponProvider,
              imageUrl: item.couponImage,
              discount: item.couponDiscount,
              discountType: item.couponDiscountType,
              rewardPoints: item.rewardPointsRequired,
              isCoinsHide: true,
              validTill: Utility().getDateFormat(
               basicInfo!.dateFormat,
                  DateTime.parse(item.validTill!)),
              isActive: item.couponStatus == COUPON_STATUS.Active.type,
            ),
          ),
        ));
  }

  Widget emptyListWidgetMaker(CouponListResponse? pageData) {
    return CustomPaginator(context).emptyListWidgetMaker(pageData,
        message: AppLocalizationsRewards.of(context)!.translate('coming_soon'));
  }
}

class CouponHistoryListPage extends StatefulWidget {
  final bool isGift;
  CouponHistoryListPage({this.isGift = false});
  @override
  _CouponHistoryListPage createState() => _CouponHistoryListPage();
}

class _CouponHistoryListPage extends State<CouponHistoryListPage> {
  GlobalKey<PaginatorState> paginatorKey = GlobalKey();
  SharedPreferences? prefs;
  String? searchVal;
  List<CommonCardData> couponList = [];
  BasicInfo? basicInfo = BasicInfo();
  @override
  void initState() {
    super.initState();
  }

  void onsearchValueChanged(String text) {
    searchVal = text;
    refresh();
  }

  refresh() {
    paginatorKey.currentState!.changeState(resetState: true);
  }

  Future<Null> refreshList() async {
    refresh();
    await new Future.delayed(new Duration(seconds: 2));

    return null;
  }

  @override
  Widget build(BuildContext context) {
    return appListCard(
      child: RefreshIndicator(
        onRefresh: refreshList,
        child: Paginator.listView(
            key: paginatorKey,
            scrollPhysics: BouncingScrollPhysics(),
            padding: EdgeInsets.only(top: 8, bottom: 8),
            pageLoadFuture: fetchList,
            pageItemsGetter: CustomPaginator(context).listItemsGetter,
            listItemBuilder: listItemBuilder,
            loadingWidgetBuilder: CustomPaginator(context).loadingWidgetMaker,
            errorWidgetBuilder: CustomPaginator(context).errorWidgetMaker,
            emptyListWidgetBuilder:
                CustomPaginator(context).emptyListWidgetMaker,
            totalItemsGetter: CustomPaginator(context).totalPagesGetter, pageErrorChecker: (CouponHistoryResponse pageData) { return false; },
         ),
      ),
    );
  }

  Future<CouponHistoryResponse> fetchList(int page) async {
    prefs ??= await SharedPreferences.getInstance();
    CouponListRequest request = CouponListRequest();
    request.personId =  basicInfo!.userId.toString();
    request.pageNumber = page;
    request.pageSize = 10;
    var data = jsonEncode(request);
    var res = await Calls().call(data, context, basicInfo!.couponLeaderList);

    return CouponHistoryResponse.fromJson(res);
  }

  Widget listItemBuilder(value, int index) {
    CouponHistoryItem item = value;
    return GestureDetector(
        onTap: () {},
        child: CouponHistoryItemCard(
          title: item.transactionType,
          dayOfMonth:
              Utility().getDateFormat("d", DateTime.parse(item.createdDate!)),
          month: Utility()
              .getDateFormat("MMM", DateTime.parse(item.createdDate!))
              .toUpperCase(),
          rewardPoints: _rewardPoints(item),
          currencyCode: item.currencyCode,
          isDeduct: _isdeduct(item),
        ));
  }

  String _rewardPoints(CouponHistoryItem item) {
    var points;
    var cr = double.parse(item.rewardsCr!).round();
    var dr = double.parse(item.rewardsDr!).round();
    if (cr != 0) {
      points = cr;
    } else if (dr != 0) {
      points = dr;
    } else {
      points = 0;
    }
    return points.toString();
  }

  bool _isdeduct(CouponHistoryItem item) {
    var points;
    var cr = double.parse(item.rewardsCr!).round();
    var dr = double.parse(item.rewardsDr!).round();
    if (cr != 0) {
      points = false;
    } else if (dr != 0) {
      points = true;
    } else {
      points = false;
    }
    return points;
  }
}

==> 0.11.1.tar.gz: lib/coupons_module/CouponsListPage.dart <==
import 'dart:convert';

import 'package:flutter/material.dart';
import 'package:loyalty_management_tool/utils/localization.dart';

import 'package:shared_preferences/shared_preferences.dart';

import '../NetworkFile/calls.dart';
import '../bloc/common_widgets/customgridDelegate.dart';
import '../models/base_res.dart';
import '../models/couponenums.dart';
import '../models/couponlisting.dart';
import '../utils/CustomPaginator.dart';
import '../utils/basicInfo.dart';
import '../utils/customcard.dart';
import '../utils/paginator.dart';
import '../utils/utility_class.dart';
import 'coupondetailpage.dart';
import 'couponhistoryitem.dart';
import 'couponlistitem.dart';
import 'gift_item_card.dart';

// ignore: must_be_immutable
class CouponsListPage extends StatefulWidget {
  Function(CouponListItem)? giftCardSelectCallback;
  Function? fetchData;
  bool isGift;

  CouponsListPage(
      {required this.giftCardSelectCallback,
      this.isGift = false,
      this.fetchData});

  @override
  _CouponsListPage createState() => _CouponsListPage();
}

class _CouponsListPage extends State<CouponsListPage> {
  GlobalKey<PaginatorState> paginatorKey = GlobalKey();
  String? searchVal;
  List<CommonCardData> couponList = [];
  SharedPreferences? prefs;
  BasicInfo? basicInfo = BasicInfo();

  @override
  void initState() {
    super.initState();
  }

  // void setSharedPreferences() async {
  //   prefs = await SharedPreferences.getInstance();
  //   refresh();
  // }

  void onsearchValueChanged(String text) {
    searchVal = text;
    refresh();
  }

  refresh() {
    paginatorKey.currentState!.changeState(resetState: true);
  }

  Future<Null> refreshList() async {
    refresh();
    await new Future.delayed(new Duration(seconds: 2));

    return null;
  }

  @override
  Widget build(BuildContext context) {
    return Container(
      child: RefreshIndicator(
        onRefresh: refreshList,
        child: Paginator.gridView(
          key: paginatorKey,
          scrollPhysics: BouncingScrollPhysics(),
          padding: EdgeInsets.only(top: 16),
          pageLoadFuture: fetchList,
          pageItemsGetter: CustomPaginator(context).listItemsGetter,
          listItemBuilder: giftItemBuilder,
          loadingWidgetBuilder: CustomPaginator(context).loadingWidgetMaker,
          errorWidgetBuilder: CustomPaginator(context).errorWidgetMaker,
          emptyListWidgetBuilder: emptyListWidgetMaker,
          totalItemsGetter: CustomPaginator(context).totalPagesGetter,
          pageErrorChecker: (data) {
            return false;
          },
          gridDelegate: SliverGridDelegateWithFixedCrossAxisCountAndFixedHeight(
              crossAxisCount: 3, height: 230),
        ),
      ),
    );
  }

  Future<CouponListResponse> fetchList(int page) async {
    prefs ??= await SharedPreferences.getInstance();
    CouponListRequest payload = CouponListRequest();
    payload.pageNumber = page;
    payload.pageSize = 20;
    payload.personId = basicInfo!.userId.toString();
    payload.entityType = widget.isGift ? "GIFT" : "GIFT,COUPON";
    var data = jsonEncode(payload);
    var res = await Calls().call(data, context, basicInfo!.rewardCouponList);

    return CouponListResponse.fromJson(res);
  }

  Widget giftItemBuilder(itemData, int index) {
    CouponListItem data = itemData;
    return InkWell(
      onTap: () {
        if (widget.isGift) {
          widget.giftCardSelectCallback!(data);
        } else {
          Navigator.push(
              context,
              MaterialPageRoute(
                  builder: (context) => CouponDetailPage(
                        couponData: data,
                        showQr: false,
                        isGift: widget.isGift,
                      ))).then((value) {});
        }
      },
      child: GiftItemCard(
        imageUrl: data.couponImage,
        title: data.couponProvider ?? "Company name",
        subtitle1: getSubtitle(data),
        subtitle2:
            "Exp. ${Utility().getDateFormat(basicInfo!.dateFormat, DateTime.parse(data.validTill!))}",
      ),
    );
  }

  String getSubtitle(CouponListItem data) {
    if (data.couponDiscountType == COUPON_DISCOUNT_TYPE.Amount.type) {
      return "${basicInfo!.currencySymbol} ${data.couponDiscount.toString()}";
    } else {
      return "${data.couponDiscount.toString()}%"
          "";
    }
  }

  Widget emptyListWidgetMaker(CouponListResponse? pageData) {
    return CustomPaginator(context).emptyListWidgetMaker(pageData,
        message: AppLocalizationsRewards.of(context)!.translate('coming_soon'));
  }
}

class RedeemedCouponsListPage extends StatefulWidget {
  final bool isGift;

  RedeemedCouponsListPage({this.isGift = false});

  @override
  _RedeemedCouponsListPage createState() => _RedeemedCouponsListPage();
}

class _RedeemedCouponsListPage extends State<RedeemedCouponsListPage> {
  GlobalKey<PaginatorState> paginatorKey = GlobalKey();
  SharedPreferences? prefs;
  String? searchVal;
  List<CommonCardData> couponList = [];
  BasicInfo? basicInfo = BasicInfo();

  @override
  void initState() {
    super.initState();
  }

  void onsearchValueChanged(String text) {
    searchVal = text;
    refresh();
  }

  refresh() {
    paginatorKey.currentState!.changeState(resetState: true);
  }

  Future<Null> refreshList() async {
    refresh();
    await new Future.delayed(new Duration(seconds: 2));
    return null;
  }

  @override
  Widget build(BuildContext context) {
    // setSharedPreferences();
    return Paginator.listView(
      key: paginatorKey,
      scrollPhysics: BouncingScrollPhysics(),
      padding: EdgeInsets.only(top: 16),
      pageLoadFuture: fetchList,
      pageItemsGetter: CustomPaginator(context).listItemsGetter,
      listItemBuilder: listItemBuilder,
      loadingWidgetBuilder: CustomPaginator(context).loadingWidgetMaker,
      errorWidgetBuilder: CustomPaginator(context).errorWidgetMaker,
      emptyListWidgetBuilder: emptyListWidgetMaker,
      totalItemsGetter: CustomPaginator(context).totalPagesGetter,
      pageErrorChecker: (CouponListResponse pageData) {
        return false;
      },
    );
  }

  Future<CouponListResponse> fetchList(int page) async {
    prefs ??= await SharedPreferences.getInstance();
    CouponListRequest payload = CouponListRequest();
    payload.pageNumber = page;
    payload.pageSize = 20;
    payload.personId = basicInfo!.toString();
    payload.entityType = widget.isGift ? 'GIFT' : "";
    var data = jsonEncode(payload);
    var res = await Calls().call(data, context, basicInfo!.myCouponList);
    return CouponListResponse.fromJson(res);
  }

  Widget listItemBuilder(value, int index) {
    CouponListItem item = value;
    return GestureDetector(
        onTap: () {
          Navigator.push(
              context,
              MaterialPageRoute(
                  builder: (context) => CouponDetailPage(
                      couponData: item, showQr: true, isGift: widget.isGift)));
        },
        child: Container(
          padding: EdgeInsets.only(left: 8, right: 8),
          child: appListCard(
            // elevation: 3,
            padding: EdgeInsets.all(0),
            child: CouponListItemCard(
              imageWidth: 124,
              imageHeight: 124,
              title: item.couponProvider,
              imageUrl: item.couponImage,
              discount: item.couponDiscount,
              discountType: item.couponDiscountType,
              rewardPoints: item.rewardPointsRequired,
              isCoinsHide: true,
              validTill: Utility().getDateFormat(
                  basicInfo!.dateFormat, DateTime.parse(item.validTill!)),
              isActive: item.couponStatus == COUPON_STATUS.Active.type,
            ),
          ),
        ));
  }

  Widget emptyListWidgetMaker(CouponListResponse? pageData) {
    return CustomPaginator(context).emptyListWidgetMaker(pageData,
        message: AppLocalizationsRewards.of(context)!.translate('coming_soon'));
  }
}

class CouponHistoryListPage extends StatefulWidget {
  final bool isGift;

  CouponHistoryListPage({this.isGift = false});

  @override
  _CouponHistoryListPage createState() => _CouponHistoryListPage();
}

class _CouponHistoryListPage extends State<CouponHistoryListPage> {
  GlobalKey<PaginatorState> paginatorKey = GlobalKey();
  SharedPreferences? prefs;
  String? searchVal;
  List<CommonCardData> couponList = [];
  BasicInfo? basicInfo = BasicInfo();

  @override
  void initState() {
    super.initState();
  }

  void onsearchValueChanged(String text) {
    searchVal = text;
    refresh();
  }

  refresh() {
    paginatorKey.currentState!.changeState(resetState: true);
  }

  Future<Null> refreshList() async {
    refresh();
    await new Future.delayed(new Duration(seconds: 2));

    return null;
  }

  @override
  Widget build(BuildContext context) {
    return appListCard(
      child: RefreshIndicator(
        onRefresh: refreshList,
        child: Paginator.listView(
          key: paginatorKey,
          scrollPhysics: BouncingScrollPhysics(),
          padding: EdgeInsets.only(top: 8, bottom: 8),
          pageLoadFuture: fetchList,
          pageItemsGetter: CustomPaginator(context).listItemsGetter,
          listItemBuilder: listItemBuilder,
          loadingWidgetBuilder: CustomPaginator(context).loadingWidgetMaker,
          errorWidgetBuilder: CustomPaginator(context).errorWidgetMaker,
          emptyListWidgetBuilder: CustomPaginator(context).emptyListWidgetMaker,
          totalItemsGetter: CustomPaginator(context).totalPagesGetter,
          pageErrorChecker: (CouponHistoryResponse pageData) {
            return false;
          },
        ),
      ),
    );
  }

  Future<CouponHistoryResponse> fetchList(int page) async {
    prefs ??= await SharedPreferences.getInstance();
    CouponListRequest request = CouponListRequest();
    request.personId = basicInfo!.userId.toString();
    request.pageNumber = page;
    request.pageSize = 10;
    var data = jsonEncode(request);
    var res = await Calls().call(data, context, basicInfo!.couponLeaderList);

    return CouponHistoryResponse.fromJson(res);
  }

  Widget listItemBuilder(value, int index) {
    CouponHistoryItem item = value;
    return GestureDetector(
        onTap: () {},
        child: CouponHistoryItemCard(
          title: item.transactionType,
          dayOfMonth:
              Utility().getDateFormat("d", DateTime.parse(item.createdDate!)),
          month: Utility()
              .getDateFormat("MMM", DateTime.parse(item.createdDate!))
              .toUpperCase(),
          rewardPoints: _rewardPoints(item),
          currencyCode: item.currencyCode,
          isDeduct: _isdeduct(item),
        ));
  }

  String _rewardPoints(CouponHistoryItem item) {
    var points;
    var cr = double.parse(item.rewardsCr!).round();
    var dr = double.parse(item.rewardsDr!).round();
    if (cr != 0) {
      points = cr;
    } else if (dr != 0) {
      points = dr;
    } else {
      points = 0;
    }
    return points.toString();
  }

  bool _isdeduct(CouponHistoryItem item) {
    var points;
    var cr = double.parse(item.rewardsCr!).round();
    var dr = double.parse(item.rewardsDr!).round();
    if (cr != 0) {
      points = false;
    } else if (dr != 0) {
      points = true;
    } else {
      points = false;
    }
    return points;
  }
}
